 Synthetic Robot Tracking Dataset

Notes
-----
Data Set Characteristics:
    :Number of time steps: 501
    :Dimensionality of Observations: 2
    :Dimensionality of States: 5
    :Creator: Pieter Abbeel
    :Date: October: 2011

This is a synthetic dataset generated by Pieter Abbeel for his Fall 2011 class
on Robotics at University of California, Berkeley.  It consists of 500
measurements 2D measurements for a robot with a 5D state space.  Data was
generated by sampling from the following generative model,

.. math::

  x_{t+1} = A x_t + b_t + e_t^1
  z_{t}   = C x_t + d_t + e_t^2
  e_t^1   \sim MultivariateNormal(0, Q)
  e_t^2   \sim MultivariateNormal(0, R)
  x_0     \sim MultivariateNormal(\mu_0, \Sigma_0)

This dataset contains the observations, true hidden states, parameters of the
initial state distribution, hidden states estimated by the Kalman Filter,
hidden states estimated by the Kalman Smoother, and covariance matrices
estimated after 50 EM iterations.

The contents are based on the contents of 'p4_starter/p4_a_data.mat' from the
following zip file,

  http://www.cs.berkeley.edu/~pabbeel/cs287-fa11/ps2/p4_starter_v2.zip

Variables not found in the mentioned mat file have been generated by a MATLAB
implementation of the Kalman Filter, Kalman Smoother, and EM algorithm.

The contents of this dataset are,

    :T: number of time steps (501)
    :data: observations corresponding to times [1...T].  Also known as :math:`z_t`
    :target: true hidden state at times [1...T]. Also known as :math:`x_t`
    :transition_matrix: transition matrix.  Also known as :math:`A`
    :transition_offsets: transition offsets. Also known as :math:`b_t`
    :observation_matrix: observation matrix. Also known as :math:`C`
    :observation_offset: observation offsets. Also known as :math:`d`
    :initial_transition_covariance: initial estimate for covariance of state
        transitions. Also known as :math:`Q_0`
    :initial_observation_covariance: initial estimate for covariance of
        observations. Also known as :math:`R_0`
    :transition_covariance: covariance of transitions after 50 EM iterations.
        Also known as :math:`Q`
    :observation_covariance: covariance of observations after 50 EM iterations.
        Also known as :math:`R`
    :initial_state_mean: mean of initial state distribution.  Also know as
        :math:`\mu_0`
    :initial_state_covariance: covariance of initial state distribution.  Also
        known as :math:`\Sigma_0`
    :filtered_state_means: mean for filtered distribution over hidden states
        estimated by a Kalman Filter using `transition_covariance` and
        `observation_covariance`
    :filtered_state_covariances: covariance for filtered distribution over
        hidden states estimated by a Kalman Filterusing `transition_covariance`
        and `observation_covariance`
    :loglikelihoods: log likelihood for 50 iterations of the EM algorithm
    :smoothed_state_means: mean for smoothed distribution over hidden state
        estimated by a Kalman Smoother using `transition_covariance` and
        `observation_covariance`
    :smoothed_state_covariances: covariance for smoothed distribution over
        hidden state estimated by a Kalman Smoother using
        `transition_covariance` and `observation_covariance`
    :DESCR: this text

References
----------

  - Abeel, Pieter (2011) Computer Science 287: Robotics
    http://www.cs.berkeley.edu/~pabbeel/cs287-fa11/
